Core Analysis Engine
--------------------

The core module contains the main analysis algorithms and data structures.

Analysis Module
---------------

.. automodule:: hbat.core.analysis
   :members:
   :undoc-members:
   :show-inheritance:

Classes
~~~~~~~

.. autoclass:: hbat.core.analysis.HBondAnalyzer
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: hbat.core.analysis.AnalysisParameters
   :members:
   :undoc-members:
   :show-inheritance:

Interaction Classes
~~~~~~~~~~~~~~~~~~~

.. autoclass:: hbat.core.analysis.MolecularInteraction
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: hbat.core.analysis.HydrogenBond
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: hbat.core.analysis.HalogenBond
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: hbat.core.analysis.PiInteraction
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: hbat.core.analysis.CooperativityChain
   :members:
   :undoc-members:
   :show-inheritance:

PDB Parser Module
-----------------

.. automodule:: hbat.core.pdb_parser
   :members:
   :undoc-members:
   :show-inheritance:

Classes
~~~~~~~

.. autoclass:: hbat.core.pdb_parser.PDBParser
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: hbat.core.pdb_parser.Atom
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: hbat.core.pdb_parser.Residue
   :members:
   :undoc-members:
   :show-inheritance:

Vector Mathematics Module
-------------------------

.. automodule:: hbat.core.vector
   :members:
   :undoc-members:
   :show-inheritance:

Classes
~~~~~~~

.. autoclass:: hbat.core.vector.Vec3D
   :members:
   :undoc-members:
   :show-inheritance:

Functions
~~~~~~~~~

.. autofunction:: hbat.core.vector.unit_vector_between

.. autofunction:: hbat.core.vector.angle_between_vectors

.. autofunction:: hbat.core.vector.dihedral_angle